(function ($, Drupal, drupalSettings) {
  'use strict';

  Drupal.behaviors.contentCalendarMain = {
    attach: function attach(context) {
      const isYearView = $(".content-calendar").hasClass('year-view');
      const isListView = $(".content-calendar").hasClass('list-view');

      // Auto scroll to current month in year/list view.
      if (isYearView || isListView && !window.location.hash) {
        let currentMonthFragment = "#" + new Date().getFullYear() + "-" + ((new Date().getMonth()) + 1);
        $(currentMonthFragment).get(0).scrollIntoView({behavior: 'instant'});
      }

    }
  };

  Drupal.behaviors.contentCalendarDrag = {
    attach: function attach(context) {
      // Drag n Drop functionality inspired by:
      // https://neliosoftware.com/blog/native-drag-and-drop-with-html5/.
      $('.calendar-entry.draggable').draggable({
        helper: 'clone'
      });

      $('.content-calendar .droppable').droppable({
        accept: '.calendar-entry.draggable',
        hoverClass: 'hovering',

        // On drop event.
        drop: function (ev, ui) {
          ui.draggable.detach();
          $(this).append(ui.draggable);

          // Get the node id from the draggable object.
          const nid = $(ui.draggable[0]).data('nid');
          // Get the date from target.
          const date = $(this).data('date');

          // Get the hour from target.
          const hour = $(this).data('hour');

          if (date && nid) {
            // Generate the URL for AJAX call.
            let url = "";
            if (hour) {
              url = Drupal.url('admin/content-calendar/update-node-publish-date/' + nid + '/' + date + '/' + hour);
            }
            else {
              url = Drupal.url('admin/content-calendar/update-node-publish-date/' + nid + '/' + date);
            }

            $.ajax({
              'url': url,
              'success': function (result) {
                if (!result.success) {
                  alert(Drupal.t('Something went wrong: @message', {
                    '@message': result.message
                  }));
                }
              },
              'error': function (xhr, status, error) {
                alert(Drupal.t('An error occurred during the update of the desired node. Please consult the watchdog.'));
              }
            });
          }
        }
      });
    }
  };
})(jQuery, Drupal, drupalSettings);
