<?php

namespace Drupal\content_calendar;

/**
 * Implements FilterHelper class.
 */
abstract class FilterHelper {

  /**
   * Get all session saved filter values.
   *
   * @return array
   *   Returns an array with filter values.
   */
  public static function getSavedSessionFilterValues() {
    $tempstore = \Drupal::service('tempstore.private')->get('content_calendar');
    $saved_active_filters = $tempstore->get('active_filters');
    if ($saved_active_filters) {
      $saved_active_filters = array_filter($saved_active_filters);
    }

    $active = FilterHelper::getActiveFilterValues();
    if ($saved_active_filters != $active) {
      $filter_plugins = \Drupal::service('plugin.manager.calendar_filter_plugin.processor');

      $query = [];
      foreach ($saved_active_filters as $id => $value) {
        $filter = $filter_plugins->getDefinition($id);
        $query[$filter['query_id']] = $value;
      }

      $query = array_filter($query);
      if (!$query) {
        return NULL;
      }

      return $query;
    }

    return NULL;
  }

  /**
   * Get all active filter values.
   *
   * @return array
   *   Returns an array with filter values.
   */
  public static function getActiveFilterValues() {
    $query = \Drupal::requestStack()->getCurrentRequest()->query->all();
    $filters = [];

    $filter_plugins = \Drupal::service('plugin.manager.calendar_filter_plugin.processor')
      ->getDefinitions();
    foreach ($filter_plugins as $plugin) {
      if (isset($query[$plugin['query_id']])) {
        $filters[$plugin['id']] = $query[$plugin['query_id']];
      }
    }

    return $filters;
  }

  /**
   * Builds the filter query slug that gets appended to the url.
   *
   * @return string
   *   A URL encoded string.
   */
  public static function buildFilterQuerySlug() {
    $filters = self::getActiveFilterValues();

    $filter_plugins = \Drupal::service('plugin.manager.calendar_filter_plugin.processor')
      ->getDefinitions();
    $query_slug = [];

    foreach ($filter_plugins as $id => $plugin) {
      if (isset($filters[$id]) && $filters[$id]) {
        $query_slug[$plugin['query_id']] = $filters[$id];
      }
    }

    return http_build_query($query_slug);
  }

}
