<?php

namespace Drupal\content_calendar\Form;

use Drupal\content_calendar\Plugin\CalendarFilterPluginManager;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Implements CalenderOverviewFilterForm class.
 */
class CalenderOverviewFilterForm extends FormBase {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * The filter plugin manager.
   *
   * @var \Drupal\content_calendar\Plugin\CalendarFilterPluginManager
   */
  protected $filterPluginManager;

  /**
   * Constructs a CalendarOverviewFilterForm object.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   * @param \Drupal\content_calendar\Plugin\CalendarFilterPluginManager $filter_plugin_manager
   *   The filter plugin manager.
   */
  public function __construct(
    EntityTypeManagerInterface $entity_type_manager,
    CalendarFilterPluginManager $filter_plugin_manager,
    ) {
    $this->entityTypeManager = $entity_type_manager;
    $this->filterPluginManager = $filter_plugin_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager'),
      $container->get('plugin.manager.calendar_filter_plugin.processor'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'calendar_overview_filter_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $params = []) {
    $filter_plugins = $this->filterPluginManager->getDefinitions();

    foreach ($filter_plugins as $plugin) {
      $plugin_instance = $this->filterPluginManager->createInstance($plugin['id']);
      $filter_config = $this->getConfig()->get('filter_configuration') ?? [];

      if (!isset($filter_config[$plugin['id']])) {
        return $form;
      }

      $form[$plugin['id']] = $plugin_instance->build();
    }

    return $form;
  }

  /**
   * Get calendar config.
   *
   * @return \Drupal\Core\Config\ImmutableConfig
   *   Config array.
   */
  protected function getConfig() {
    $config = $this->config(SettingsForm::CONFIG_NAME);

    return $config;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {}

}
