<?php

namespace Drupal\content_calendar\Plugin\CalendarFilter;

use Drupal\content_calendar\Plugin\CalendarFilterPluginBase;
use Drupal\Core\Database\Query\SelectInterface;

/**
 * Title filter.
 *
 * @CalendarFilterPlugin(
 *   id = "title",
 *   label = @Translation("Search by title"),
 *   weight = 0,
 *   query_id = "title"
 * )
 */
class Title extends CalendarFilterPluginBase {

  /**
   * {@inheritdoc}
   */
  public function build() {

    $build = [];
    $definition = $this->getPluginDefinition();
    $filter_settings = $this->getSettings();

    if (!$filter_settings['enable']) {
      return;
    }

    $widget = $this->filterWidgetPluginManager()
      ->createInstance(
        $filter_settings['widget']
    );

    $build = $widget->build([
      'id' => $this->getPluginId(),
      'label' => $definition['label'],
      'query_key' => $definition['query_id'],
    ]);
    $build['#weight'] = $definition['weight'];

    return $build;
  }

  /**
   * {@inheritdoc}
   */
  public function alterQuery(SelectInterface $query, $value) {
    if (!$value) {
      return;
    }

    $query->condition("nfd.title", "%" . $value . "%", "LIKE");

    return $query;
  }

  /**
   * {@inheritdoc}
   */
  public function ignoredWidgets() {
    return [
      "checkboxes",
      "select",
      "list",
      "checkboxes_or",
    ];
  }

}
