<?php

namespace Drupal\content_calendar\Plugin;

use Drupal\Component\Plugin\PluginInspectionInterface;
use Drupal\Core\Database\Query\SelectInterface;

/**
 * Defines an interface for CalendarFilterPlugin plugins.
 */
interface CalendarFilterPluginInterface extends PluginInspectionInterface {

  /**
   * Builds the filter settings form.
   *
   * @return array
   *   Render array.
   */
  public function buildSettingsForm();

  /**
   * Builds the filter display view.
   *
   * @return array
   *   Render array.
   */
  public function build();

  /**
   * Alters the calendar node query.
   *
   * @param \Drupal\Core\Database\Query\SelectInterface $query
   *   Database query.
   * @param string $value
   *   Active filter value.
   *
   * @return \Drupal\Core\Database\Query\SelectInterface|void
   *   Altered database query.
   */
  public function alterQuery(SelectInterface $query, $value);

  /**
   * Get filter settings.
   *
   * @return arary
   *   Filter settings.
   */
  public function getSettings();

}
