<?php

namespace Drupal\content_calendar\Plugin\CalendarFilterWidget;

use Drupal\content_calendar\Plugin\CalendarFilterWidgetPluginBase;
use Drupal\Core\Url;

/**
 * List widget for calendar filter.
 *
 * @CalendarFilterWidgetPlugin(
 *   id = "list",
 *   label = @Translation("List"),
 * )
 */
class ListFilterWidget extends CalendarFilterWidgetPluginBase {

  /**
   * {@inheritdoc}
   */
  public function build(array $settings) {
    $build = $this->buildFilterForm($this->t("@label", ["@label" => $settings['label']]), $settings['query_key']);

    $build['filter']['#attributes']['class'] = ['list-filter'];

    $route_name = $this->getCurrentRouteName();

    // Special case for the default route.
    if ($route_name === "content_calendar.view_calendar") {
      $default_tab = $this->configFactory()->get('default_tab');

      switch ($default_tab) {
        case "day":
          $route_name = "content_calendar.calendar_day";
          break;

        case "week":
          $route_name = "content_calendar.calendar_week";
          break;

        case "month":
          $route_name = "content_calendar.calendar_month";
          break;

        case "year":
          $route_name = "content_calendar.calendar_year";
          break;

        case "content":
          $route_name = "content_calendar.calendar_list";
          break;
      }
    }

    $route_params = $this->routeMatch()->getParameters()->all();

    $build_key = "";
    if ($settings['id'] == "taxonomy") {
      $build_key = $settings['vid'] . "_term_value";
    }
    else {
      $build_key = $settings['id'];
    }

    foreach ($settings['options'] as $id => $value) {
      $build['filter']['list'][] = [
        '#prefix' => "<div>",
        '#suffix' => "</div>",
        '#attributes' => [
          'data-id' => $id,
        ],
        '#type' => 'link',
        '#title' => $value,
        '#url' => Url::fromRoute(
          $route_name,
          $route_params,
          [
            "query" => [
              $settings['query_key'] => $id,
            ],
          ]
        ),
      ];
    }

    $select_widget_instance = $this->getCalendarFilterWidgetManager()->createInstance('select', []);
    $select_widget_build = $select_widget_instance->build($settings);
    $build['filter'][$build_key] = $select_widget_build['filter'][$build_key];

    $build['#attached']['library'][] = "content_calendar/list_filter_widget";

    return $build;
  }
}
