<?php

namespace Drupal\content_kanban\Form;

use Drupal\content_calendar\Plugin\CalendarFilterPluginManager;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\content_planner\ContentModerationService;
use Drupal\content_calendar\Form\SettingsForm as CalendarSettingsForm;

/**
 * Implements KanbanFilterForm class.
 */
class KanbanFilterForm extends FormBase {

  /**
   * The Content Moderation service.
   *
   * @var \Drupal\content_planner\ContentModerationService
   */
  protected $contentModerationService;

  /**
   * An array with the form params.
   *
   * @var array
   */
  protected $formParams = [];

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * The filter plugin manager.
   *
   * @var \Drupal\content_calendar\Plugin\CalendarFilterPluginManager
   */
  protected $filterPluginManager;

  /**
   * {@inheritdoc}
   */
  public function __construct(ContentModerationService $content_moderation_service, EntityTypeManagerInterface $entity_type_manager, CalendarFilterPluginManager $filter_plugin_manager) {
    $this->contentModerationService = $content_moderation_service;
    $this->entityTypeManager = $entity_type_manager;
    $this->filterPluginManager = $filter_plugin_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('content_planner.content_moderation_service'),
      $container->get('entity_type.manager'),
      $container->get('plugin.manager.calendar_filter_plugin.processor')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'content_kanban_filter_form';
  }

  /**
   * Get calendar config.
   *
   * @return \Drupal\Core\Config\ImmutableConfig
   *   Config array.
   */
  protected function getCalendarConfig() {
    $config = $this->config(CalendarSettingsForm::CONFIG_NAME);

    return $config;
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $params = []) {
    $filter_plugins = $this->filterPluginManager->getDefinitions();

    foreach ($filter_plugins as $plugin) {
      $plugin_instance = $this->filterPluginManager->createInstance($plugin['id']);
      $filter_config = $this->getCalendarConfig()->get('filter_configuration') ?? [];

      if (!isset($filter_config[$plugin['id']])) {
        return $form;
      }

      $form[$plugin['id']] = $plugin_instance->build();
    }

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {

  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
  }

}
