<?php

namespace Drupal\content_kanban;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\EntityListBuilder;
use Drupal\Core\Entity\Query\QueryInterface;
use Drupal\Core\Link;
use Drupal\Core\Url;

/**
 * Defines a class to build a listing of Kanban Log entities.
 *
 * @ingroup content_kanban
 */
class KanbanLogListBuilder extends EntityListBuilder
{

  /**
   * {@inheritdoc}
   */
  protected function getEntityListQuery(): QueryInterface
  {
    $query = $this->getStorage()->getQuery()
      ->accessCheck(TRUE)
      ->sort('created', 'DESC');

    // Only add the pager if a limit is specified.
    if ($this->limit) {
      $query->pager($this->limit);
    }
    return $query;
  }

  /**
   * {@inheritdoc}
   */
  public function buildHeader()
  {

    $header['id'] = $this->t('Kanban Log ID');
    $header['name'] = $this->t('Name');
    $header['workflow'] = $this->t('Workflow');
    $header['entity'] = $this->t('Entity / Entity ID');
    $header['state_from'] = $this->t('State from');
    $header['state_to'] = $this->t('State to');

    return $header + parent::buildHeader();
  }

  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface $entity)
  {

    /** @var \Drupal\content_kanban\Entity\KanbanLog $entity */

    $row['id'] = $entity->id();
    $row['name'] = $entity->label();

    // Workflow.
    if ($workflow = $entity->getWorkflow()) {
      $row['workflow'] = $workflow->label();
    } else {
      $row['workflow'] = $this->t('Workflow with ID @id does not exist anymore', ['@id' => $entity->getWorkflowId()]);
    }

    if ($logEntity = $entity->getEntityObject()) {
      $row['entity'] = new Link($logEntity->label(), $logEntity->toUrl());
    } else {
      $row['entity'] = $this->t('Entity @entity_type with ID @id does not exist anymore', [
        '@id' => $entity->getEntityId(),
        '@entity_type' => $entity->getType(),
      ]);
    }

    $row['state_from'] = $entity->getStateFrom();
    $row['state_to'] = $entity->getStateTo();

    return $row + parent::buildRow($entity);
  }

  /**
   * {@inheritdoc}
   */
  public function render()
  {
    $build['clear_button'] = [
      '#type' => "link",
      '#title' => $this->t("Flush all Kanban entries"),
      '#attributes' => [
        'class' => [
          'button',
          'button--primary',
        ],
      ],
      '#url' => Url::fromRoute("content_kanban.logs.flush"),
    ];

    $build['content'] = parent::render();

    return $build;
  }

}
