<?php

namespace Drupal\content_planner\Access;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Routing\Access\AccessInterface;

/**
 * Checks access for displaying the content planner dashboard based on configured roles.
 */
class DashboardAccessCheck implements AccessInterface {

  /**
   * A custom access check.
   *
   * @param \Drupal\Core\Session\AccountInterface $account
   *   Run access checks for this account.
   *
   * @return \Drupal\Core\Access\AccessResultInterface
   *   The access result.
   */
  public function checkAccess(AccountInterface $account) {
    $dashboard_id = 'master';
    $dashboard_settings_service = \Drupal::service('content_planner.dashboard_settings_service');

    if ($id = \Drupal::routeMatch()->getParameter('dashboard_id')) {
      $dashboard_id = $id;
    }

    // Get the dashboard configuration, including roles.
    if ($account->hasPermission('administer content planner')) {
      return AccessResult::allowed();
    }
    $dashboard_configuration = $dashboard_settings_service->getDashboardConfigurations($dashboard_id);
    if (isset($dashboard_configuration['roles'])) {
      // Check if the user has one of the configured roles.
      foreach ($dashboard_configuration['roles'] as $role) {
        if ($account->hasPermission('administer content planner') || $account->hasRole($role)) {
          return AccessResult::allowed();
        }
      }
    }

    // If no roles are configured, or the user does not have any of the roles, deny access.
    return AccessResult::forbidden();
  }

}
