<?php

namespace Drupal\content_planner;

use Drupal\Component\Plugin\PluginInspectionInterface;

/**
 * Defines an interface for dashboard type plugins.
 */
interface DashboardTypeInterface extends PluginInspectionInterface {

  /**
   * Return the id of the type.
   *
   * @return string
   *   The name of the block.
   */
  public function getId(): string;

  /**
   * Return the name of the type.
   *
   * @return string
   *   The label of the block.
   */
  public function getLabel(): string;

  /**
   * Get the canonical route of the dashboard type.
   *
   * @return string
   *   The route name.
   */
  public function getCanonicalRouteName(): string;

  /**
   * Get the base route name.
   *
   * @return string
   *   The route name.
   */
  public function getBaseRouteName(): string;

  /**
   * Array of route parameters to build the base route.
   *
   * @return array
   *   Array with parameter names.
   */
  public function getBaseRouteParameters(): array;

  /**
   * Return the base dashboard id.
   *
   * @return string
   *   Dashboard id.
   */
  public function getBaseDashboardId(): string;

  /**
   * Get the info if its an entity.
   *
   * @return bool
   *   Returns TRUE if supports entity.
   */
  public function isEntity(): bool;

  /**
   * Get entity type.
   *
   * @return string
   *   Returns entity type.
   */
  public function getEntityType(): ?string;

  /**
   * Return the dashboard local tasks.
   *
   * @return array
   *   Array of main local tasks.
   */
  public function getLocalTasks(): array;

  /**
   * Return the dashboard page title.
   *
   * @param string $dashboard_id
   *   Dashboard id.
   *
   * @return string
   *   Dashboard id.
   */
  public function getPageTitle(string $dashboard_id): string;

  /**
   * Build the dashboard content.
   *
   * @param string $dashboard_id
   *   Dashboard id.
   * @param \Drupal\content_planner\DashboardTypeInterface $dashboard_type
   *   Dashboard type.
   *
   * @return string
   *   Dashboard id.
   */
  public function buildDashboardContent(string $dashboard_id, DashboardTypeInterface $dashboard_type): array;

}
