<?php

namespace Drupal\content_planner\Form;

use Drupal\Core\Form\ConfirmFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Link;
use Drupal\Core\Url;

/**
 * Form to delete a dashboard.
 */
class DashboardDeleteForm extends ConfirmFormBase {

  /**
   * The dashboard id.
   *
   * @var string
   */
  protected $dashboardId;

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'content_planner_dashboard_delete_form';
  }

  /**
   * {@inheritdoc}
   */
  public function getQuestion() {
    return $this->t('Are you sure you want to delete the dashboard %dashboard?', ['%dashboard' => $this->dashboardId]);
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelUrl() {
    return new Url('content_planner.dashboards.list');
  }

  /**
   * {@inheritdoc}
   */
  public function getDescription() {
    return $this->t('This action cannot be undone.');
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $dashboard_id = NULL) {
    $this->dashboardId = $dashboard_id;

    // Prevent deletion of the master dashboard.
    if ($this->dashboardId === 'master') {
      $this->messenger()->addError($this->t('The master dashboard cannot be deleted.'));

      $url = Url::fromRoute('content_planner.dashboards.list');
      $link = Link::fromTextAndUrl($this->t('Go back to dashboard tabs administration'), $url)->toString();

      $form['back_link'] = [
        '#type' => 'markup',
        '#markup' => $link,
        '#prefix' => '<p>',
        '#suffix' => '</p>',
      ];

      return $form;
    }

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Perform the deletion of the dashboard configuration.
    \Drupal::service('content_planner.dashboard_settings_service')
      ->deleteDashboardConfigurations(
        $this->dashboardId
      );

    // Set a message and redirect to the main dashboard page.
    $this->messenger()->addMessage($this->t('Dashboard %dashboard has been deleted.', ['%dashboard' => $this->dashboardId]));
    $form_state->setRedirect(
      'content_planner.content_planner.dashboard',
      [
        'dashboard_id' => 'master',
      ]
    );
    drupal_flush_all_caches();
  }

}
