<?php

namespace Drupal\content_planner\Plugin\DashboardBlock;

use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\content_planner\DashboardBlockBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\HttpFoundation\Request;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;

/**
 * Provides a custom html block for Content Planner Dashboard.
 *
 * @DashboardBlock(
 *   id = "custom_html_block",
 *   name = @Translation("Generic HTML Widget"),
 *   category = "General",
 *   id_category = "general"
 * )
 */
class CustomHtmlBlock extends DashboardBlockBase implements ContainerFactoryPluginInterface
{

  use StringTranslationTrait;

  /**
   * Builds the render array for the block.
   *
   * @return array
   *   The render array for the block.
   */
  public function build()
  {


    $build = [];

    // Get config.
    $config = $this->getConfiguration();


    if (!empty($config['plugin_specific_config']['content']['value']) && $config['plugin_specific_config']['content']['value']) {
      $build['content'] = [
        '#markup' => check_markup($config['plugin_specific_config']['content']['value'], $config['plugin_specific_config']['content']['format']),
      ];
    } else {
      $build['content'] = [
        '#markup' => 'No content provided. Please configure the widget.',
      ];
    }





    return $build;
  }

  /**
   * {@inheritdoc}
   */
  public function getConfigSpecificFormFields(FormStateInterface &$form_state, Request &$request, array $block_configuration)
  {

    $form = [];

    if (!empty($block_configuration['plugin_specific_config']['content']['value'])) {
      $default_value = $block_configuration['plugin_specific_config']['content']['value'];
    } else {
      $default_value = '';
    }

    $form['content'] = [
      '#type' => 'text_format',
      '#title' => $this->t('Content'),
      '#format' => 'full_html',
      '#default_value' => $default_value,
    ];



    return $form;
  }

}

