<?php

namespace Drupal\content_planner\Plugin\DashboardBlock;

use Drupal\content_planner\DashboardBlockBase;
use Drupal\Core\Block\BlockManagerInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Request;

/**
 * Provides a Block Widget for Content Planner Dashboard.
 *
 * @DashboardBlock(
 *   id = "drupal_block_widget",
 *   name = @Translation("Drupal Block Widget"),
 *   category = "General",
 *   id_category = "general"
 * )
 */
class DrupalBlockWidget extends DashboardBlockBase implements ContainerFactoryPluginInterface {

  use StringTranslationTrait;

  /**
   * The block manager.
   *
   * @var \Drupal\Core\Block\BlockManagerInterface
   */
  protected $blockManager;

  public function __construct(array $configuration, $plugin_id, $plugin_definition, BlockManagerInterface $block_manager) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->blockManager = $block_manager;
  }

  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('plugin.manager.block')
    );
  }

  public function build() {
    $config = $this->getConfiguration();
    $block_id = $config['plugin_specific_config']['block_id'] ?? '';

    if ($block_id) {
      $block_instance = $this->blockManager->createInstance($block_id, []);
      if ($block_instance->access(\Drupal::currentUser())) {
        return $block_instance->build();
      }
    }

    return ['#markup' => $this->t('Please configure the widget.')];
  }

  public function getConfigSpecificFormFields(FormStateInterface &$form_state, Request &$request, array $block_configuration) {
    $form = [];
    $block_options = [];

    // Retrieve all block plugin definitions.
    $blocks = $this->blockManager->getDefinitions();
    foreach ($blocks as $block_id => $block_definition) {
      if (!empty($block_definition['admin_label'])) {
        $block_options[$block_id] = $block_definition['admin_label'];
      }
    }

    $selected_block = $block_configuration['plugin_specific_config']['block_id'] ?? '';

    $form['block_id'] = [
      '#type' => 'select',
      '#title' => $this->t('Select Block'),
      '#options' => $block_options,
      '#default_value' => $selected_block,
      '#required' => TRUE,
    ];

    return $form;
  }
}
