<?php

namespace Drupal\content_planner\Plugin\DashboardBlock;

use Drupal\content_planner\DashboardBlockBase;
use Drupal\Core\Link;
use Drupal\Core\Url;
use Drupal\Core\Database\Database;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;

/**
 * Provides a 'Watchdog Summary' block.
 *
 * @DashboardBlock(
 *   id = "watchdog_summary",
 *   name = @Translation("Watchdog Summary"),
 *   category = "System",
 *   id_category = "system"
 * )
 */
class WatchdogSummary extends DashboardBlockBase implements ContainerFactoryPluginInterface
{

  /**
   * {@inheritdoc}
   */
  public function build()
  {
    $build = [];
    $database = Database::getConnection();
    $query = $database->select('watchdog', 'w');
    $query->fields('w', ['severity']);
    $query->addExpression('COUNT(wid)', 'count');
    $query->groupBy('severity');
    $result = $query->execute();

    // Manually define the severity levels mapping
    $severity_levels = [
      0 => $this->t('Emergency'),
      1 => $this->t('Alert'),
      2 => $this->t('Critical'),
      3 => $this->t('Error'),
      4 => $this->t('Warning'),
      5 => $this->t('Notice'),
      6 => $this->t('Info'),
      7 => $this->t('Debug'),
    ];

    $total_entries = 0;
    $build['stats']['#prefix'] = '<div class="watchdog-summary">';
    $build['stats']['#suffix'] = '</div>';

    while ($record = $result->fetchAssoc()) {
      $severity_name = isset($severity_levels[$record['severity']]) ? strtolower($severity_levels[$record['severity']]) : 'unknown';
      $count = $record['count'];
      $total_entries += $count;

      $url = Url::fromRoute('dblog.overview', [], ['query' => ['severity[]' => $record['severity']]]);

      $linkText = $this->t('@severity<div>@count</div>', ['@severity' => $severity_levels[$record['severity']], '@count' => $count]);
      $link = Link::fromTextAndUrl($linkText, $url)->toString();

      // Use the severity name for the CSS class
      $build['stats']['severity_' . $record['severity']] = [
        '#markup' => $link,
        '#prefix' => "<div class=\"watchdog-severity watchdog-severity-{$severity_name}\">",
        '#suffix' => '</div>',
      ];
    }

    // Use the severity name for the CSS class
    $build['stats']['total'] = [
      '#markup' =>  'Total<div>'.$total_entries.'</div>',
      '#prefix' => "<div class=\"watchdog-severity\">",
      '#suffix' => '</div>',
    ];

    $linkText = $this->t('Go to watchdog');
    $url = Url::fromRoute(
      'dblog.overview',
      [],
      [
        'attributes' => ['class' => ['button', 'button--secondary', 'button--small']]
      ]
    );




    $watchdog_link = Link::fromTextAndUrl($linkText, $url)->toString();

    $build['summary'] = [
      '#type' => 'html_tag',
      '#tag' => 'div',
      '#attributes' => [
        'class' => ['watchdog-summary'],
        'style' => 'margin-top: 0px;'
      ],
    ];
    $build['summary']['watchdog_link'] = [
      '#markup' => $watchdog_link,
      '#prefix' => '<div class="watchdog-total">',
      '#suffix' => '</div>',
    ];


    return $build;
  }


}
